@@ -165,7 +165,7 @@ glade_xml_new(const char *fname, const char *root, const char *domain)
  * @root: the root widget node (or %NULL for none)
  * @domain: the translation domain (or %NULL for the default)
  *
- * This routine can be used by bindings (such as gtk--) to help construct
+ * This routine can be used by bindings (such as gtkmm) to help construct
  * a GladeXML object, if it is needed.
  *
  * Returns: TRUE if the construction succeeded.
@@ -193,6 +193,45 @@ glade_xml_construct (GladeXML *self, const char *fname, const char *root,
     return TRUE;
 }
 
+/**
+ * glade_xml_construct_from_buffer:
+ * @self: the GladeXML object
+ * @buffer: the memory buffer containing the XML document.
+ * @size: the size of the buffer.
+ * @root: the root widget node (or %NULL for none)
+ * @domain: the translation domain (or %NULL for the default)
+ *
+ * In order to use this method you must already have a GladeXML
+ * object.  This two step creation process is typically used only 
+ * by language bindings, such as gtkmm, while constructing GladeXML 
+ * objects from compiled-in buffers, at runtime.
+ *
+ * Returns: TRUE if the construction succeeded.
+ */
+gboolean   
+glade_xml_construct_from_buffer (GladeXML *self, const char *buffer, int size,
+					  const char *root,
+					  const char *domain)
+{
+    GladeInterface *iface;
+
+    g_return_val_if_fail(self != NULL, FALSE);
+    g_return_val_if_fail(self->priv->tree == NULL, FALSE);
+
+    iface = glade_parser_parse_buffer(buffer, size, domain);
+
+    if (!iface)
+	return FALSE;
+
+    self->priv->tree = iface;
+    if (self->filename)
+	g_free(self->filename);
+    self->filename = NULL;
+    glade_xml_build_interface(self, iface, root);
+
+    return TRUE;
+}
+
 /**
  * glade_xml_new_from_buffer:
  * @buffer: the memory buffer containing the XML document.
@@ -212,16 +251,14 @@ GladeXML *
 glade_xml_new_from_buffer(const char *buffer, int size, const char *root,
 			  const char *domain)
 {
-    GladeXML *self;
-    GladeInterface *iface = glade_parser_parse_buffer(buffer, size, domain);
-
-    if (!iface)
-	return NULL;
-    self = g_object_new(GLADE_TYPE_XML, NULL);
-
-    self->priv->tree = iface;
-    self->filename = NULL;
-    glade_xml_build_interface(self, iface, root);
+    GladeXML *self = g_object_new(GLADE_TYPE_XML, NULL);
+    self->filename = NULL; /* Not required if g_object_new guarantees filename is NULL.  I do not know if it does. */
+    if( !glade_xml_construct_from_buffer(self, buffer, size, root, domain) )
+    {
+       /* Clean up, the parser was unable to load the object */
+       g_object_unref(self);
+       return NULL;
+    }
 
     return self;
 }
@@ -313,6 +350,10 @@ autoconnect_foreach(const char *signal_handler, GList *signals,
  * the signal handler names given in the interface description with
  * symbols in the application and connects the signals.
  * 
+ * You should add gmodule-export-2.0 to your pkg-config checks to ensure 
+ * that your application's executable exports the signal handlers. This is not 
+ * necessary if the signal handlers are in a shared library.
+ *
  * Note that this function will not work correctly if gmodule is not
  * supported on the platform.
  */
